// Copyright 2014 Google Inc.

#import <Foundation/Foundation.h>

/**
 * @file GCKGameError.h
 * Includes GCKGameError definition and GCKGameStatusCode enum
 */

/**
 * @enum GCKGameStatusCode
 * Description of error codes
 */
typedef NS_ENUM(NSInteger, GCKGameStatusCode) {
  /**
   * Status code indicating the request is invalid or contains invalid parameters.
   */
  GCKGameStatusCodeInvalidRequest = 1,

  /**
   * Status code indicating that the request was disallowed and could not be completed.
   */
  GCKGameStatusCodeNotAllowed = 2,

  /**
   * Status code indicating the Game Service SDK version in the request does not match the version
   * expected by the game service running on the receiver.
   */
  GCKGameStatusCodeIncorrectVersion = 3,

  /**
   * Status code indicating the number of players connected and available on the receiver is
   * greater than the maximum number of players specified in the configuration object for the
   * receiver game.
   */
  GCKGameStatusCodeTooManyPlayers = 4
};

/**
 * The key for the customData JSON object associated with the error in the userInfo dictionary.
 */
GCK_EXTERN NSString *const kGCKGameErrorCustomDataKey;

/**
 * The class for all GCK Game framework errors.
 *
 * @ingroup Utilities
 */
GCK_EXPORT
@interface GCKGameError : NSError

/**
 * Returns the name of the enum value for a given error code.
 * @param code The {@link GCKGameStatusCode} to look up.
 */
+ (NSString *)enumDescriptionForCode:(GCKGameStatusCode)code;
@end

